==> applitutoriel-js-lite-5.3.0.tgz: package/src/services/page/par/par-rpa-service-page-impl.ts <==
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * applitutoriel-js-lite - Application tutoriel utilisant le Framework hornet
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.3.0
 * @link git+https://github.com/diplomatiegouvfr/applitutoriel-modules.git
 * @license CECILL-2.1
 */


import { Utils } from "hornet-js-utils";
import { Logger } from "hornet-js-utils/src/logger";
import { HornetRequest } from "hornet-js-core/src/services/hornet-superagent-request";
import { MediaType } from "hornet-js-core/src/protocol/media-type";
import {
    URL_PAR_EXPORTER,
    URL_PAR_EXPORTER_OFD,
    URL_PAR_RECHERCHE,
    URL_PAR_SUPPRESSION_MASSE,
    URL_PARTENAIRES
} from "applitutoriel-js-common/src/utils/urls";
import { PartenaireResult } from "applitutoriel-js-common/src/services/type/par/par-types";
import { FichePartenaireServiceImpl } from "src/services/page/par/par-fpa-service-page-impl";
import { BusinessError } from "hornet-js-utils/src/exception/business-error";
import { SecteurServiceImpl } from "src/services/page/adm/secteur-service-page-impl";
import { PartenaireRechercheParameter } from "applitutoriel-js-common/src/services/type/par/par-rpa-prm";
import { FichePartenaire } from "applitutoriel-js-common/src/services/type/par/fpa-par-type";
import { RecherchePartenaireService } from "applitutoriel-js-common/src/services/page/par/par-rpa-service";

const logger: Logger = Utils.getLogger("applitutoriel.services.page.par.par-rpa-service-page-impl");

/**
 * Implementation des services pour les partenanires
 * @class
 * @implements {RecherchePartenaireService}
 * @extends {ServiceApi}
 */
export class RecherchePartenaireServiceImpl extends RecherchePartenaireService {

    /** service des gestion des partenaires */
    private fichePartenaireApi: FichePartenaireServiceImpl = new FichePartenaireServiceImpl();

    /** service des gestion des secteurs */
    private secteurApi: SecteurServiceImpl = new SecteurServiceImpl();

    /**
     * liste les produits
     * @return Promise
     */
    rechercher(criteres: PartenaireRechercheParameter, reqMimeType: MediaType): Promise<any> {
        logger.trace("SERVICES - rechercher : ", criteres, reqMimeType);
        let request: HornetRequest = {
            url: this.buildUrl(URL_PARTENAIRES + URL_PAR_RECHERCHE),
            method: "post",
            data: criteres,
            typeMime: reqMimeType
        };
        return this.fetch(request);

    }

    supprimerPage(id): Promise<any> {
        return this.fichePartenaireApi.fichePartenaire(id).then((partenaire: FichePartenaire) => {
            if (partenaire.vip) {
                throw new BusinessError("ERR_PARTENAIRE_VIP_SUPPRESSION", { $1: partenaire.nom, $2: partenaire.prenom });
            }
            return this.fetch({ method: "delete", url: this.buildUrl(URL_PARTENAIRES + "/" + id) });
        });
    }

    supprimer(id): Promise<any> {
        logger.trace("SERVICES - supprimer : ", id);
        return this.fetch({ method: "delete", url: this.buildUrl(URL_PARTENAIRES + "/" + id) });
    }

    supprimerEnMasse(partenaires: PartenaireResult[]): Promise<any> {
        logger.trace("SERVICES - supprimerEnMasse :", partenaires);

        logger.debug("Envoi d'une liste de partenaires à supprimer :", partenaires);

        return this.fetch({
            method: "post",
            url: this.buildUrl(URL_PARTENAIRES + URL_PAR_SUPPRESSION_MASSE),
            data: partenaires
        });
    }

    exporter(reqMimeType: MediaType, criteres: PartenaireRechercheParameter): Promise<any> {
        logger.trace("SERVICES - exporter : ", reqMimeType);
        return this.fetch({
            method: "post",
            url: this.buildUrl(URL_PARTENAIRES + URL_PAR_EXPORTER),
            data: criteres,
            typeMime: reqMimeType
        });
    }

    exporterODF(reqMimeType: MediaType, criteres?: PartenaireRechercheParameter): Promise<any> {
        logger.trace("SERVICES - exporterODF : ", reqMimeType);
        return this.fetch({
            method: "post",
            url: this.buildUrl(URL_PARTENAIRES + URL_PAR_EXPORTER_OFD),
            data: criteres,
            typeMime: reqMimeType
        });
    }

    listerSecteurs(): Promise<any> {
        return this.secteurApi.lister();
    }
}

==> applitutoriel-js-lite-5.4.1.tgz: package/src/services/page/par/par-rpa-service-page-impl.ts <==
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * applitutoriel-js-lite - Application tutoriel utilisant le Framework hornet
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.4.1
 * @link git+https://github.com/diplomatiegouvfr/applitutoriel-modules.git
 * @license CECILL-2.1
 */


import { Logger } from "hornet-js-logger/src/logger";
import { HornetRequest } from "hornet-js-core/src/services/hornet-superagent-request";
import { MediaType } from "hornet-js-core/src/protocol/media-type";
import {
    URL_PAR_EXPORTER,
    URL_PAR_EXPORTER_OFD,
    URL_PAR_RECHERCHE,
    URL_PAR_SUPPRESSION_MASSE,
    URL_PARTENAIRES } from "applitutoriel-js-common/src/utils/urls";
import { PartenaireResult } from "applitutoriel-js-common/src/services/type/par/par-types";
import { FichePartenaireServiceImpl }  from "applitutoriel-js-lite/src/services/page/par/par-fpa-service-page-impl";
import { BusinessError } from "hornet-js-utils/src/exception/business-error";
import { SecteurServiceImpl }  from "applitutoriel-js-lite/src/services/page/adm/secteur-service-page-impl";
import { PartenaireRechercheParameter } from "applitutoriel-js-common/src/services/type/par/par-rpa-prm";
import { FichePartenaire } from "applitutoriel-js-common/src/services/type/par/fpa-par-type";
import { RecherchePartenaireService } from "applitutoriel-js-common/src/services/page/par/par-rpa-service";
import { Promise } from "hornet-js-utils/src/promise-api";

const logger: Logger = Logger.getLogger("applitutoriel.services.page.par.par-rpa-service-page-impl");

/**
 * Implementation des services pour les partenanires
 * @class
 * @implements {RecherchePartenaireService}
 * @extends {ServiceApi}
 */
export class RecherchePartenaireServiceImpl extends RecherchePartenaireService {

    /** service des gestion des partenaires */
    private fichePartenaireApi: FichePartenaireServiceImpl = new FichePartenaireServiceImpl();

    /** service des gestion des secteurs */
    private secteurApi: SecteurServiceImpl = new SecteurServiceImpl();

    /**
     * liste les produits
     * @return Promise
     */
    rechercher(criteres: PartenaireRechercheParameter, reqMimeType: MediaType): Promise<any> {
        logger.trace("SERVICES - rechercher : ", criteres, reqMimeType);
        let request: HornetRequest = {
            url: this.buildUrl(URL_PARTENAIRES + URL_PAR_RECHERCHE),
            method: "post",
            data: criteres,
            typeMime: reqMimeType
        };
        return this.fetch(request);

    }

    supprimerPage(id): Promise<any> {
        return this.fichePartenaireApi.fichePartenaire(id).then((partenaire: FichePartenaire) => {
            if (partenaire.vip) {
                throw new BusinessError("ERR_PARTENAIRE_VIP_SUPPRESSION", { $1: partenaire.nom, $2: partenaire.prenom });
            }
            return this.fetch({ method: "delete", url: this.buildUrl(URL_PARTENAIRES + "/" + id) });
        });
    }

    supprimer(id): Promise<any> {
        logger.trace("SERVICES - supprimer : ", id);
        return this.fetch({ method: "delete", url: this.buildUrl(URL_PARTENAIRES + "/" + id) });
    }

    supprimerEnMasse(partenaires: PartenaireResult[]): Promise<any> {
        logger.trace("SERVICES - supprimerEnMasse :", partenaires);

        logger.debug("Envoi d'une liste de partenaires à supprimer :", partenaires);

        return this.fetch({
            method: "post",
            url: this.buildUrl(URL_PARTENAIRES + URL_PAR_SUPPRESSION_MASSE),
            data: partenaires
        });
    }

    exporter(reqMimeType: MediaType, criteres: PartenaireRechercheParameter): Promise<any> {
        logger.trace("SERVICES - exporter : ", reqMimeType);
        return this.fetch({
            method: "post",
            url: this.buildUrl(URL_PARTENAIRES + URL_PAR_EXPORTER),
            data: criteres,
            typeMime: reqMimeType
        });
    }

    exporterODF(reqMimeType: MediaType, criteres?: PartenaireRechercheParameter): Promise<any> {
        logger.trace("SERVICES - exporterODF : ", reqMimeType);
        return this.fetch({
            method: "post",
            url: this.buildUrl(URL_PARTENAIRES + URL_PAR_EXPORTER_OFD),
            data: criteres,
            typeMime: reqMimeType
        });
    }

    listerSecteurs(): Promise<any> {
        return this.secteurApi.lister();
    }
}
